==> volkanic-0.3.1.tar.gz: volkanic-0.3.1/volkanic/system.py <==
#!/usr/bin/env python3
# coding: utf-8

from __future__ import unicode_literals

import contextlib
import importlib
import os

from volkanic.utils import query_attr, load_symbol, load_variables
from volkanic.cmdline import CommandRegistry

__compat_symbols = [
    load_symbol,
    load_variables,
    CommandRegistry,
]


@contextlib.contextmanager
def remember_cwd():
    curdir = os.getcwd()
    try:
        yield
    finally:
        os.chdir(curdir)


class CommandNotFound(KeyError):
    pass


# deprecated
class CommandConf(object):
    def __init__(self, commands):
        self.commands = dict(commands)
        self.commands.setdefault('_global', {})

    @classmethod
    def _from_file(cls, name, loader, default_dir=None):
        path = cls._locate(name, default_dir)
        return cls(loader(open(path)))

    @classmethod
    def from_yaml(cls, name, default_dir=None):
        import yaml
        ext = os.path.splitext(name)[1].lower()
        if ext not in ['.yml', '.yaml']:
            name += '.yml'
        return cls._from_file(name, yaml.safe_load, default_dir)

    @classmethod
    def from_json(cls, name, default_dir=None):
        import json
        return cls._from_file(name, json.load, default_dir)

    @classmethod
    def from_json5(cls, name, default_dir=None):
        import json5
        return cls._from_file(name, json5.load, default_dir)

    @staticmethod
    def _locate(path, default_dir):
        paths = [path]
        if default_dir is not None:
            paths.append(os.path.join(default_dir, path))
        for path in paths:
            if os.path.isfile(path):
                return path
        raise FileNotFoundError(path)

    @staticmethod
    def _execute(params):
        # only 'module' is a must-have
        prefix = params.get('prefix', '')
        module = prefix + params['module']
        call = params.get('call', 'run')
        args = params.get('args', [])
        kwargs = params.get('kwargs', {})
        if not isinstance(args, (list, tuple)):
            args = [args]
        m = importlib.import_module(module)
        query_attr(m, *call.split('.'))(*args, **kwargs)

    def __call__(self, cmd):
        if cmd not in self.commands:
            raise CommandNotFound(str(cmd))
        params = dict(self.commands['_global'])
        params.update(self.commands[cmd])
        with remember_cwd():
            os.chdir(params.get('cd', '.'))
            self._execute(params)

    @classmethod
    def run(cls, prog=None, args=None, default_dir=None, **kwargs):
        from argparse import ArgumentParser
        kwargs.setdefault('description', 'volkanic command-conf runner')
        parser = ArgumentParser(prog=prog, **kwargs)
        parser.add_argument('name', help='a YAML file')
        parser.add_argument(
            'key', nargs='?', default='default',
            help='a top-level key in the YAML file',
        )
        ns = parser.parse_args(args=args)
        cconf = cls.from_yaml(ns.name, default_dir)
        cconf(ns.key)

==> volkanic-0.3.3.tar.gz: volkanic-0.3.3/volkanic/system.py <==
#!/usr/bin/env python3
# coding: utf-8

from __future__ import unicode_literals

import importlib
import os

from volkanic.cmdline import CommandRegistry, remember_cwd
from volkanic.utils import query_attr, load_symbol, load_variables

__compat_symbols = [
    load_symbol,
    load_variables,
    CommandRegistry,
]


class CommandNotFound(KeyError):
    pass


# deprecated
class CommandConf(object):
    def __init__(self, commands):
        self.commands = dict(commands)
        self.commands.setdefault('_global', {})

    @classmethod
    def _from_file(cls, name, loader, default_dir=None):
        path = cls._locate(name, default_dir)
        return cls(loader(open(path)))

    @classmethod
    def from_yaml(cls, name, default_dir=None):
        import yaml
        ext = os.path.splitext(name)[1].lower()
        if ext not in ['.yml', '.yaml']:
            name += '.yml'
        return cls._from_file(name, yaml.safe_load, default_dir)

    @classmethod
    def from_json(cls, name, default_dir=None):
        import json
        return cls._from_file(name, json.load, default_dir)

    @classmethod
    def from_json5(cls, name, default_dir=None):
        import json5
        return cls._from_file(name, json5.load, default_dir)

    @staticmethod
    def _locate(path, default_dir):
        paths = [path]
        if default_dir is not None:
            paths.append(os.path.join(default_dir, path))
        for path in paths:
            if os.path.isfile(path):
                return path
        raise FileNotFoundError(path)

    @staticmethod
    def _execute(params):
        # only 'module' is a must-have
        prefix = params.get('prefix', '')
        module = prefix + params['module']
        call = params.get('call', 'run')
        args = params.get('args', [])
        kwargs = params.get('kwargs', {})
        if not isinstance(args, (list, tuple)):
            args = [args]
        m = importlib.import_module(module)
        query_attr(m, *call.split('.'))(*args, **kwargs)

    def __call__(self, cmd):
        if cmd not in self.commands:
            raise CommandNotFound(str(cmd))
        params = dict(self.commands['_global'])
        params.update(self.commands[cmd])
        with remember_cwd():
            os.chdir(params.get('cd', '.'))
            self._execute(params)

    @classmethod
    def run(cls, prog=None, args=None, default_dir=None, **kwargs):
        from argparse import ArgumentParser
        kwargs.setdefault('description', 'volkanic command-conf runner')
        parser = ArgumentParser(prog=prog, **kwargs)
        parser.add_argument('name', help='a YAML file')
        parser.add_argument(
            'key', nargs='?', default='default',
            help='a top-level key in the YAML file',
        )
        ns = parser.parse_args(args=args)
        cconf = cls.from_yaml(ns.name, default_dir)
        cconf(ns.key)
